# Conductor - lifx-async

Navigation hub for project context.

## Quick Links

- [Product Definition](./product.md)
- [Product Guidelines](./product-guidelines.md)
- [Tech Stack](./tech-stack.md)
- [Workflow](./workflow.md)
- [Tracks](./tracks.md)

## Active Tracks

- [ ] [hsbk-rgb-float_20260318](./tracks/hsbk-rgb-float_20260318/index.md) — Update HSBK RGB Conversion to Float

<!-- Auto-populated by /conductor:new-track -->

## Getting Started

Run `/conductor:new-track` to create your first feature track.
